import os
import time

from PyQt5 import QtWidgets, uic
from qgis.gui import QgsMapToolEmitPoint, QgsMapToolPan

FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'ui', 'affect_radiometry_slab.ui'))


class CtrlCraftAffectUpdateMapTool(QgsMapToolEmitPoint):
    def __init__(self, affect, teneur_up, teneur_low):
        QgsMapToolEmitPoint.__init__(self, affect.master.canvas)
        self.affect = affect
        self.teneur_up = teneur_up
        self.teneur_low = teneur_low

    def canvasReleaseEvent(self, event):
        pt = event.mapPoint()

        if self.affect.master.data.is_valid():
            self.affect.master.data.affect_radiometry_slab_degraded(self.teneur_up,
                                                                       self.teneur_low,
                                                                       pt.asWkt())
            self.affect.master.canvas.refreshAllLayers()
            self.affect.master.iface.messageBar().pushMessage(
                                              """Sonde haute : {}
                                              Sonde basse : {}
                                              """.format(str(round(self.teneur_up,2)),str(round(self.teneur_low,2))),
                                              duration=5)
        self.affect.master.canvas.setMapTool(QgsMapToolPan(self.affect.master.canvas))


class CtrlCraftAffectSonde(QtWidgets.QDialog, FORM_CLASS):
    def __init__(self, parent=None):
        """Constructor."""
        super(CtrlCraftAffectSonde, self).__init__(parent)
        self.setupUi(self)

class CtrlCraftAffectRadiometrySlab(object):
    def __init__(self, master):
        self.master = master
        self.mapTool = None

    def activateMapTool(self, _, __):
        dlg = CtrlCraftAffectSonde()
        dlg.show()
        ret = dlg.exec_()
        if not ret:
            return

        teneur_up = 0
        teneur_low = 0
        degraded = all([x == '-1' for x in [self.master.rtkube.widget.GNSSLat.text(), self.master.rtkube.widget.GNSSLon.text(), self.master.rtkube.widget.GNSSAlt.text()]])

        for i in range(1,5):
            percent = i / float(4) * 100
            time.sleep(1)
            if degraded:
                if (dlg.gammaSonde.currentIndex() == 0):
                    teneur_up  += float(self.master.rtkube.widget.gammaTUp.text())
                else:
                    teneur_low += float(self.master.rtkube.widget.gammaTLow.text())

        if degraded:
            self.master.iface.messageBar().pushMessage("You can now point the slab")
            self.mapTool = CtrlCraftAffectUpdateMapTool(self, teneur_up / 4.0,
                                                        teneur_low / 4.0)
            self.master.canvas.setMapTool(self.mapTool)
        else:
            self.master.data.affect_radiometry_slab(dlg.gammaSonde.currentIndex() == 0)
            self.master.canvas.refreshAllLayers()
            print(self.master.data.get_average_last_four_radiometry())
            up, low = self.master.data.get_average_last_four_radiometry()
            if (dlg.gammaSonde.currentIndex() == 0):
                low = 0
            else:
                up = 0
            self.master.iface.messageBar().pushMessage(
                                              """Sonde haute : {}
                                              Sonde basse : {}
                                              """.format(str(round(up,2)),str(round(low,2))),
                                              duration=5)


