# -*- coding: utf-8 -*-
"""
/***************************************************************************
 CtrlCraftDialog
                                 A QGIS plugin
 Areva - plugin for displaying 3D mines
                             -------------------
        begin                : 2017-09-12
        git sha              : $Format:%H$
        copyright            : (C) 2017 by Oslandia
        email                : sylvain.beorchia@oslandia.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""

from builtins import range
import os

from PyQt5 import uic
from PyQt5.QtWidgets import (QDialog,
                         QAbstractItemView,
                         QTableWidgetItem,
                         QTableWidget)
from PyQt5.QtGui import QColor

from CtrlCraft import CtrlCraftLogger

FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'ui', 'base.ui'))


class CtrlCraftOfficeShipmentsTable(QDialog, FORM_CLASS):

    def __init__(self, data, parent=None):
        """Constructor."""
        super(CtrlCraftOfficeShipmentsTable, self).__init__(parent)
        self.setupUi(self)
        self.data = data

    def init(self, deposit, panel, blast):
        # 1/ get the CSV from the operator (portique)
        # 2/ mix the portic data with the mobile data

        # Read data portic from CSV
        # porticData = self.data.portic_data()

        # Read DB Slab data
        shipments = self.data.shipments(deposit, panel, blast)

        # Build the table
        table = QTableWidget()
        table.setEditTriggers(QAbstractItemView.NoEditTriggers)

        # initiate table
        table.setRowCount(len(shipments))

        colColors = [None, None, None, None, QColor(246, 255, 213),
                     None, QColor(255, 170, 170), QColor(255, 170, 170),
                     QColor(198, 240, 255)]

        nbCols = len(colColors)
        table.setColumnCount(nbCols)

        table.setHorizontalHeaderLabels(
                (self.tr('Slabs'), self.tr('Deposit'), self.tr('Panel'), self.tr('Blast'), self.tr('Truck'),
                 self.tr('Unload Datetime'), self.tr('Mean estimated radiometry'),
                 self.tr('Mean probe radiometry'), self.tr('Gate radiometry'))
        )

        item = table.horizontalHeaderItem(0)
        item.setToolTip(self.tr('Number of slabs in the shipment'))

        item = table.horizontalHeaderItem(1)
        item.setToolTip(self.tr('Deposit where slabs have been taken'))

        item = table.horizontalHeaderItem(2)
        item.setToolTip(self.tr('Panel where slabs have been taken'))

        item = table.horizontalHeaderItem(3)
        item.setToolTip(self.tr('Blast where slabs have been taken'))

        item = table.horizontalHeaderItem(4)
        item.setToolTip(self.tr('Name of the truck'))

        item = table.horizontalHeaderItem(5)
        item.setToolTip(self.tr('Datetime of the unloading'))

        item = table.horizontalHeaderItem(6)
        item.setToolTip(self.tr('Mean estimated radiometry for all slabs in the shipment'))

        item = table.horizontalHeaderItem(7)
        item.setToolTip(self.tr('Mean probe radiometry for all slabs in the shipment'))

        item = table.horizontalHeaderItem(8)
        item.setToolTip(self.tr('Radiometry of the shipment measured by the gate'))

        # set data
        tRow = 0
        gateids = []

        for shipment in shipments:
            for col in range(0, nbCols-1):
                table.setItem(tRow, col, QTableWidgetItem(shipment[col]))
                if colColors[col]:
                    table.item(tRow, col).setBackground(colColors[col])

            tRow += 1

            truck = shipment[4]
            unload_time = shipment[5]

            if not unload_time:
                continue

            # do not use seconds because the portic datetime is in minutes
            # only
            times = unload_time.split(':')
            unload_time = '{}:{}'.format(times[0], times[1])

            data = self.data.gate_data_entry(deposit, panel, blast,
                                             truck, unload_time)

            if not data:
                continue

            gateid = data[0]
            if gateid in gateids:
                continue
            gateids.append(gateid)

            radiometry = data[1]
            item = QTableWidgetItem('{}'.format(radiometry))

            table.setItem(tRow-1, 8, item)
            if colColors[8]:
                col = colColors[8]
                table.item(tRow-1, 8).setBackground(col)

        table.horizontalHeader().setStretchLastSection(True)
        table.resizeColumnsToContents()

        self.vLayout.addWidget(table)
